.. _ref-edfreader:

.. currentmodule:: pyedflib

This section describes functions used to perform reading of a EDF/BDF file.

EDF/BDF file reader ``edfreader``
---------------------------------

.. autoclass:: EdfReader
    :members:
    :undoc-members:
    :show-inheritance:
